@@ -89,7 +89,7 @@ class OvfConfigFile(SharedConfigFile):
     def download(self, logger=None):
         header_comment = (
             '# Editing the hosted engine VM is only possible via'
-            ' the manager UI\API\n'
+            ' the manager UI/API\n'
             '# This file was generated at {}\n'
             '\n'
         ).format(time.asctime())
